#ifndef NT2_INCLUDE_FUNCTIONS_NEXTAFTER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEXTAFTER_HPP_INCLUDED

#include <nt2/ieee/include/functions/nextafter.hpp>

#endif
